@@ -232,7 +232,7 @@ class Scale_and_shift(object):
 
 class Space_evenly(object):
     """Space the points evenly in time over the complete recording. The
-       parameter 'number' defines how many"""
+       parameter 'number' defines how many."""
     def __init__(self, number=100, kind='cubic'):
         self.number = number
         self.kind = kind
@@ -344,7 +344,7 @@ class Space_evenly(object):
 
 
 class Space_evenly_per_stroke(object):
-    """Space the points evenly for every single stroke seperatly. """
+    """Space the points evenly for every single stroke seperatly."""
     def __init__(self, number=100, kind='cubic'):
         self.number = number
         self.kind = kind
@@ -416,9 +416,8 @@ class Space_evenly_per_stroke(object):
 
 
 class Douglas_peucker(object):
-    """
-     Apply the Douglas-Peucker algorithm to each stroke of $pointlist
-     seperately.
+    """Apply the Douglas-Peucker algorithm to each stroke of pointlist
+       seperately.
     """
     def __init__(self, EPSILON):
         self.EPSILON = EPSILON
@@ -657,7 +656,7 @@ class Wild_point_filter(object):
 
 
 class Weighted_average_smoothing(object):
-    """Smooth every stroke by a weighted average. """
+    """Smooth every stroke by a weighted average."""
     def __init__(self, theta):
         """Theta is a list of 3 non-negative numbers"""
         assert len(theta) == 3, \
